==> huaweicloudsdkddm-3.1.134-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/show_risk_info_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowRiskInfoResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'risks': 'list[Risks]'
    }

    attribute_map = {
        'risks': 'risks'
    }

    def __init__(self, risks=None):
        """ShowRiskInfoResponse

        The model defined in huaweicloud sdk

        :param risks: 内核风险提醒信息。
        :type risks: list[:class:`huaweicloudsdkddm.v1.Risks`]
        """
        
        super(ShowRiskInfoResponse, self).__init__()

        self._risks = None
        self.discriminator = None

        if risks is not None:
            self.risks = risks

    @property
    def risks(self):
        """Gets the risks of this ShowRiskInfoResponse.

        内核风险提醒信息。

        :return: The risks of this ShowRiskInfoResponse.
        :rtype: list[:class:`huaweicloudsdkddm.v1.Risks`]
        """
        return self._risks

    @risks.setter
    def risks(self, risks):
        """Sets the risks of this ShowRiskInfoResponse.

        内核风险提醒信息。

        :param risks: The risks of this ShowRiskInfoResponse.
        :type risks: list[:class:`huaweicloudsdkddm.v1.Risks`]
        """
        self._risks = risks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowRiskInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkddm-3.1.159-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/show_risk_info_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowRiskInfoResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'risks': 'list[Risks]'
    }

    attribute_map = {
        'risks': 'risks'
    }

    def __init__(self, risks=None):
        r"""ShowRiskInfoResponse

        The model defined in huaweicloud sdk

        :param risks: 内核风险提醒信息。
        :type risks: list[:class:`huaweicloudsdkddm.v1.Risks`]
        """
        
        super(ShowRiskInfoResponse, self).__init__()

        self._risks = None
        self.discriminator = None

        if risks is not None:
            self.risks = risks

    @property
    def risks(self):
        r"""Gets the risks of this ShowRiskInfoResponse.

        内核风险提醒信息。

        :return: The risks of this ShowRiskInfoResponse.
        :rtype: list[:class:`huaweicloudsdkddm.v1.Risks`]
        """
        return self._risks

    @risks.setter
    def risks(self, risks):
        r"""Sets the risks of this ShowRiskInfoResponse.

        内核风险提醒信息。

        :param risks: The risks of this ShowRiskInfoResponse.
        :type risks: list[:class:`huaweicloudsdkddm.v1.Risks`]
        """
        self._risks = risks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowRiskInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
